# Changelog

## 0.3.0 (Oct 23, 2025)

- new Grid helper class to simplify access to clues
- support for reading and writing files in AcrossLite text format
- bug fix (courtesy @afontenot) to allow serialized dicts to have ':' in values

## 0.2.6 (Jun 12, 2024)

- Add NotProvided value to SolutionState enum for puzzles without a
  solution
- typo in Markup.is_markup_square
- utf-8 support for v2 files
- various fixes for diagramless

## 0.2.5 (Jun 7, 2019)

- added support for puz file version 1.4

## 0.2.4 (March 15, 2019)

- minor bug fixes

## 0.2.3 (October 24, 2016)

- Incremented version number as needed for for PyPI.

## 0.2.2 (October 24, 2016)

- Added support for Python 2.6

## 0.2.1 (December 19, 2014)

- Added version string to puz module for version detection.

## 0.2 (December 19, 2014)

- Added support for Python 3.2+.
- Fixed issue where tests were not added properly to TestSuite.

## 0.1 (February 16, 2014)

- Initial release.
